@@ -45,15 +45,29 @@ class LandApp(ProcessModel):
         # Mixing the Incoming flow with soil
         self.Mixed_flow = mix(self.Inc_flow, self.Soil_flow)
 
-        # Calculating the volume of percipitation (includes RunOff and Leachate)
-        Percip_Vol = self.Inc_flow.ts / self.InputData.LandApp['appl_dens']['amount'] * self.InputData.Percip['ann_precip']['amount'] * 1000  # L/yr
-        Leachate_Vol = Percip_Vol * self.InputData.Percip['frac_leach']['amount']  # L/yr
-        RunOff_Vol = Percip_Vol * self.InputData.Percip['frac_runoff']['amount']  # L/yr
+        # PFAS loss to volatilization
+        self.Volatilized = Flow()
+        self.Volatilized.PFAS = self.Mixed_flow.PFAS * self.InputData.Volatilization['frac_vol_loss']['amount']
+        self.Mixed_flow.PFAS = self.Mixed_flow.PFAS - self.Volatilized.PFAS
+
+        # Calculating the volume of precipitation (includes RunOff and Leachate)
+        Precip_Vol = self.Inc_flow.ts / self.InputData.LandApp['appl_dens']['amount'] * self.InputData.Precip['ann_precip']['amount'] * 1000  # L/yr
+        total = self.InputData.Precip['frac_ET']['amount']+self.InputData.Precip['frac_runoff']['amount']
+        if total > 1:
+            self.InputData.Precip['frac_ET']['amount'] /= total
+            self.InputData.Precip['frac_runoff']['amount'] /= total
+
+        ET_Vol = Precip_Vol * self.InputData.Precip['frac_ET']['amount']  # L/yr
+        RunOff_Vol = Precip_Vol * self.InputData.Precip['frac_runoff']['amount']  # L/yr
+        Leachate_Vol = Precip_Vol - ET_Vol - RunOff_Vol
+        if Leachate_Vol < 0 and Leachate_Vol > -0.0001:
+            Leachate_Vol = 0.0
 
         # Calculating the PFAS in water and soil partitions
         self.Remaining, self.Leachate, self.RunOff = soil_sorption(self.Mixed_flow, self.InputData.LogPartCoef, Leachate_Vol, RunOff_Vol)
 
         # add to Inventory
+        self.Inventory.add('Volatilized', self.Name, 'Air', self.Volatilized)
         self.Inventory.add('Leachate', self.Name, 'Water', self.Leachate)
         self.Inventory.add('RunOff', self.Name, 'Water', self.RunOff)
         self.Inventory.add('Remaining', self.Name, 'Soil', self.Remaining)
@@ -72,11 +86,13 @@ class LandApp(ProcessModel):
     def report(self, normalized=False):
         report = pd.DataFrame(index=self.Inc_flow._PFAS_Index)
         if not normalized:
-            report['Remaining'] = self.Remaining.PFAS
+            report['Volatilized'] = self.Volatilized.PFAS
+            report['Remaining in Soil'] = self.Remaining.PFAS
             report['Leachate'] = self.Leachate.PFAS
-            report['RunOff'] = self.RunOff.PFAS
+            report['Runoff'] = self.RunOff.PFAS
         else:
-            report['Remaining'] = self.Remaining.PFAS / self.Inc_flow.PFAS
-            report['Leachate'] = self.Leachate.PFAS / self.Inc_flow.PFAS
-            report['RunOff'] = self.RunOff.PFAS / self.Inc_flow.PFAS
+            report['Volatilized'] = round(self.Volatilized.PFAS / self.Inc_flow.PFAS * 100, 2)
+            report['Remaining in Soil'] = round(self.Remaining.PFAS / self.Inc_flow.PFAS * 100, 2)
+            report['Leachate'] = round(self.Leachate.PFAS / self.Inc_flow.PFAS * 100, 2)
+            report['Runoff'] = round(self.RunOff.PFAS / self.Inc_flow.PFAS * 100, 2)
         return(report)
