@@ -32,11 +32,13 @@ class SCWO(ProcessModel):
         self.Steam = Flow()
         self.Slurry = Flow()
         self.Effluent = Flow()
+        self.Destroyed = Flow()
 
         for i in self.Inc_flow._PFAS_Index:
             self.Effluent.PFAS[i] = self.Inc_flow.PFAS[i] * (1 - self.InputData.DRE[i]['amount'])
             self.Slurry.PFAS[i] = self.Inc_flow.PFAS[i] * self.InputData.DRE[i]['amount'] * self.InputData.SCWO['frac_PFAS_to_slurry']['amount']
             self.Steam.PFAS[i] = self.Inc_flow.PFAS[i] * self.InputData.DRE[i]['amount'] * self.InputData.SCWO['frac_PFAS_to_steam']['amount']
+        self.Destroyed.PFAS = self.Inc_flow.PFAS - self.Effluent.PFAS - self.Slurry.PFAS - self.Steam.PFAS
 
         # Volume balance
         self.Slurry.vol = self.Inc_flow.vol * self.InputData.SCWO['frac_water_to_slurry']['amount']
@@ -45,6 +47,7 @@ class SCWO(ProcessModel):
 
         # add to Inventory
         self.Inventory.add('Effluent', self.Name, 'Water', self.Effluent)
+        self.Inventory.add('Destroyed', self.Name, 'Destroyed', self.Destroyed)
 
     def products(self):
         Products = {}
@@ -65,8 +68,10 @@ class SCWO(ProcessModel):
             report['Effluent'] = self.Effluent.PFAS
             report['Slurry'] = self.Slurry.PFAS
             report['Steam'] = self.Steam.PFAS
+            report['Destroyed'] = self.Destroyed.PFAS
         else:
-            report['Effluent'] = self.Effluent.PFAS / self.Inc_flow.PFAS
-            report['Slurry'] = self.Slurry.PFAS / self.Inc_flow.PFAS
-            report['Steam'] = self.Steam.PFAS / self.Inc_flow.PFAS
+            report['Effluent'] = round(self.Effluent.PFAS / self.Inc_flow.PFAS * 100, 2)
+            report['Slurry'] = round(self.Slurry.PFAS / self.Inc_flow.PFAS * 100, 2)
+            report['Steam'] = round(self.Steam.PFAS / self.Inc_flow.PFAS * 100, 2)
+            report['Destroyed'] = round(self.Destroyed.PFAS / self.Inc_flow.PFAS * 100, 2)
         return(report)
