@@ -34,12 +34,14 @@ class ThermalTreatment(ProcessModel):
         self.Exhaust = Flow()
         self.Destructed = Flow()
         for i in self.Inc_flow._PFAS_Index:
-            self.Exhaust.PFAS[i] = self.Inc_flow.PFAS[i] * (1 - self.InputData.DRE[i]['amount'])
-            self.CombRes.PFAS[i] = self.Inc_flow.PFAS[i] * self.InputData.DRE[i]['amount'] * self.InputData.Frac_to_res[i]['amount']
-            self.Destructed.PFAS[i] = self.Inc_flow.PFAS[i] * self.InputData.DRE[i]['amount'] * (1 - self.InputData.Frac_to_res[i]['amount'])
+            self.Exhaust.PFAS[i] = self.Inc_flow.PFAS[i] * (1 - self.InputData.DRE[i]['amount']) * (1 - self.InputData.Frac_to_res[i]['amount'])
+            self.Destructed.PFAS[i] = self.Inc_flow.PFAS[i] * self.InputData.DRE[i]['amount']
+            self.CombRes.PFAS[i] = self.Inc_flow.PFAS[i] - self.Destructed.PFAS[i] - self.Exhaust.PFAS[i]
 
         # Combustion Residual
-        self.CombRes.ts = self.Inc_flow.ts * self.InputData.Comb_param['frac_sol_to_res']['amount']
+        self.CombRes.ts = self.Inc_flow.VS * self.InputData.Comb_param['frac_vs_to_res']['amount'] + (self.Inc_flow.ts - self.Inc_flow.VS)
+        self.CombRes.VS = self.Inc_flow.VS * self.InputData.Comb_param['frac_vs_to_res']['amount']
+        self.CombRes.C = self.Inc_flow.C * self.InputData.Comb_param['frac_vs_to_res']['amount']
         self.CombRes.mass = self.CombRes.ts / self.InputData.Comb_param['res_ts_cont']['amount']
         self.CombRes.moist = self.CombRes.mass - self.CombRes.ts
 
@@ -62,11 +64,11 @@ class ThermalTreatment(ProcessModel):
     def report(self, normalized=False):
         report = pd.DataFrame(index=self.Inc_flow._PFAS_Index)
         if not normalized:
-            report['Exhaust'] = self.Exhaust.PFAS
-            report['CombustionResiduals'] = self.CombRes.PFAS
+            report['Air Emission'] = self.Exhaust.PFAS
+            report['Combustion Residuals'] = self.CombRes.PFAS
             report['Destructed'] = self.Destructed.PFAS
         else:
-            report['Exhaust'] = self.Exhaust.PFAS / self.Inc_flow.PFAS
-            report['CombustionResiduals'] = self.CombRes.PFAS / self.Inc_flow.PFAS
-            report['Destructed'] = self.Destructed.PFAS / self.Inc_flow.PFAS
+            report['Air Emission'] = round(self.Exhaust.PFAS / self.Inc_flow.PFAS * 100, 2)
+            report['Combustion Residuals'] = round(self.CombRes.PFAS / self.Inc_flow.PFAS * 100, 2)
+            report['Destructed'] = round(self.Destructed.PFAS / self.Inc_flow.PFAS * 100, 2)
         return(report)
