@@ -14,18 +14,11 @@ def test_project():
 
     InputFlow = ps.IncomFlow()
 
-    InputFlow.InputData.FoodWaste['C_cont'] = {'Name': 'Incoming organic C content - dry',
-                                               'amount': 0.5,
-                                               'unit': 'fraction TS',
-                                               'uncertainty_type': 3,
-                                               'loc': 0.5,
-                                               'scale': 0.05}
-
     InputFlow.set_flow('FoodWaste', 1000)
 
     demo = ps.Project(InventoryObject, CommonDataObjct, ProcessModels=None)
     ProcessSet = demo.get_process_set(InputFlow.Inc_flow)
-    demo.set_process_set(ProcessSet)
+    demo.set_process_set(ProcessSet[0])
     FlowParams = demo.get_flow_params()
     demo.set_flow_params(FlowParams)
     demo.setup_network()
